summaryrefslogtreecommitdiff
path: root/tcwg_bmk-build.sh
diff options
context:
space:
mode:
authorMaxim Kuvyrkov <maxim.kuvyrkov@linaro.org>2021-10-22 18:50:43 +0000
committerMaxim Kuvyrkov <maxim.kuvyrkov@linaro.org>2021-10-22 18:50:43 +0000
commitd49d354a411deadf2fc00c07ccd78921673894da (patch)
tree9baf847c6a6348cd1c67d3d9163d16a681e9daa6 /tcwg_bmk-build.sh
parent270b40a92a824f7fa5d23ccb14339d2a1c72acc9 (diff)
tcwg_bmk-build.sh: Adjust workaround for new "console" behavior
Change-Id: I9cfd697213812be4df0a451a9b99fdb9b23d36c7
Diffstat (limited to 'tcwg_bmk-build.sh')
-rwxr-xr-xtcwg_bmk-build.sh24
1 files changed, 15 insertions, 9 deletions
diff --git a/tcwg_bmk-build.sh b/tcwg_bmk-build.sh
index e4a347a7..483be346 100755
--- a/tcwg_bmk-build.sh
+++ b/tcwg_bmk-build.sh
@@ -291,13 +291,18 @@ benchmark ()
-p image_arch="$image_arch" \
${scripts_branch+-p scripts_branch="$scripts_branch"} \
${bmk_branch+-p bmk_branch="$bmk_branch"} \
- | tee $run_step_artifacts/benchmark.log
+ | tee $run_step_artifacts/benchmark-build.log
local build_num
- build_num=$(head -n1 $run_step_artifacts/benchmark.log \
+ build_num=$(head -n1 $run_step_artifacts/benchmark-build.log \
| sed -e "s/Started.*#\([0-9]\+\).*/\1/")
assert_with_msg "Benchmark build number should not be 0!" \
- [ "$build_num" -gt "0" ]
+ [ "$build_num" -gt "0" ]
+
+ # The "build" output adds "Completed <build>" to the console output.
+ # Strip this last line.
+ head -n -1 $run_step_artifacts/benchmark-build.log \
+ > $run_step_artifacts/benchmark.log
local build_status
local build_ret
@@ -320,14 +325,15 @@ benchmark ()
;;
esac
# After ci.linaro.org update on 2021-10-11 behavior of console's "-f"
# option has changed -- for finished builds it exited immediately before
# the update, and after the update "console -f" hangs indefinitely.
# This makes us use busy-wait cycle here.
sleep 300
- remote_exec "ci.linaro.org:2222::-l $USER@linaro.org" \
- console tcwg-benchmark $build_num \
+ (timeout 1m \
+ ssh -p2222 -l $USER@linaro.org ci.linaro.org \
+ console tcwg-benchmark $build_num || true) \
| tee $run_step_artifacts/benchmark.log
done
@@ -320,14 +325,15 @@ benchmark ()
;;
esac
- # After ci.linaro.org update on 2021-10-11 behavior of console's "-f"
- # option has changed -- for finished builds it exited immediately before
- # the update, and after the update "console -f" hangs indefinitely.
- # This makes us use busy-wait cycle here.
+ # After ci.linaro.org update on 2021-10-11 behavior of console command
+ # option has changed: before the update it exited immediately for finished builds,
+ # and after the update "console" hangs indefinitely for finished builds.
+ # We workaround this by using "timeout 1m".
sleep 300